import webiopi
import time

import sys,os
sys.path.append(os.path.dirname(os.path.abspath(__file__)))
import myremocon

webiopi.setDebug()

GPIO = webiopi.GPIO

PIN_IRSENSOR = 27
PIN_IRLED    = 17
PIN_BUTTONS = [6, 13, 19, 26]
PIN_STATELED = 5
DEBOUNCEDELAY = 0.5

COUNT_BUTTON = len(PIN_BUTTONS)
g_abState_Button_prev = []	# ボタンの前回の状態（デバウンス処理用）
g_adSec_Button_prev = []			# ボタンの状態が「OFF→ON」した前回の時刻（デバウンス処理用）
g_aiPushed_Button = []		# ボタンの押下状態（ボタン同時押し処理用）

def setup():
	global g_abState_Button_prev
	global g_adSec_Button_prev
	global g_aiPushed_Button

	GPIO.setFunction( PIN_IRSENSOR, GPIO.IN )

	GPIO.setFunction( PIN_IRLED, GPIO.OUT )
	GPIO.digitalWrite( PIN_IRLED, False )

	for i in range(COUNT_BUTTON):
		GPIO.setFunction( PIN_BUTTONS[i], GPIO.IN )
		g_abState_Button_prev.append( False )
		g_adSec_Button_prev.append( time.time() )
		g_aiPushed_Button.append( 0 )

	GPIO.setFunction( PIN_STATELED, GPIO.OUT )
	GPIO.digitalWrite( PIN_STATELED, False )

	myremocon.setup()

def loop():
	global g_abState_Button_prev
	global g_adSec_Button_prev
	global g_aiPushed_Button

	dSec = time.time()

	# ボタンが押されたかどうか
	for iIndexButton in range(COUNT_BUTTON):
		bButtonState = GPIO.digitalRead( PIN_BUTTONS[iIndexButton] )
		if False == g_abState_Button_prev[iIndexButton] \
		 and True == bButtonState:
			if DEBOUNCEDELAY < (dSec - g_adSec_Button_prev[iIndexButton]):
				webiopi.debug( "Unestablished : Button pushed : " + str(iIndexButton) )
				g_aiPushed_Button[iIndexButton] = 1
			g_adSec_Button_prev[iIndexButton] = dSec
		g_abState_Button_prev[iIndexButton] = bButtonState

	# 端の２つのボタンの同時押下判定。同時押下の場合は、学習モードに移行する。
	iCountPushedButton = 0;
	for iIndexButton in range(COUNT_BUTTON):
		if 1 == g_aiPushed_Button[iIndexButton]:
			iCountPushedButton += 1
	if 2 <= iCountPushedButton:
		for iIndexButton in range(COUNT_BUTTON):
			g_aiPushed_Button[iIndexButton] = 0	# ボタン押下状態のクリア
		webiopi.debug( "Established : Multiple button pushed" )
		myremocon.learn( PIN_IRSENSOR, PIN_BUTTONS, PIN_STATELED )
		return

	# 単独のボタン押下判定（デバウンス時間分遅延して判定）
	for iIndexButton in range(COUNT_BUTTON):
		if 1 == g_aiPushed_Button[iIndexButton] \
		 and DEBOUNCEDELAY < (dSec - g_adSec_Button_prev[iIndexButton]):
			g_aiPushed_Button[iIndexButton] = 0;
			webiopi.debug( "Established : Button pushed : " + str(iIndexButton) )
			result = myremocon.send( PIN_IRLED, iIndexButton )
			webiopi.debug( "Send result : " + str(result) )

# Webブラウザからの信号送信要求時の処理
@webiopi.macro
def SendSignal( buttonID ):
	webiopi.debug( "SendSignal : Button" + buttonID )
	result = myremocon.send( PIN_IRLED, int(buttonID) )
	webiopi.debug( "Send result : " + str(result) )
	return result
